<?php

namespace Pinpoint\RedirectManager\Controller\Adminhtml\Redirects;

use Magento\Backend\App\Action;
use Magento\Backend\App\Action\Context;

/**
 * Class UploadCsv
 * @package Pinpoint\RedirectManager\Controller\Adminhtml\Redirects
 */
class UploadCsv extends Action
{
    /**
     * @var \Pinpoint\RedirectManager\Model\RedirectFactory
     */
    protected $redirectFactory;

    /**
     * UploadCsv constructor.
     * @param Context $context
     * @param \Pinpoint\RedirectManager\Model\RedirectFactory $redirectFactory
     */
    public function __construct(
        Context $context,
        \Pinpoint\RedirectManager\Model\RedirectFactory $redirectFactory
    ) {
        $this->redirectFactory = $redirectFactory;
        parent::__construct($context);
    }

    /**
     * Check the permission to run it
     *
     * @return boolean
     */
    protected function _isAllowed()
    {
        return $this->_authorization->isAllowed('Pinpoint_RedirectManager::redirect_manager');
    }

    /**
     * @return \Magento\Framework\App\ResponseInterface
     */
    public function execute()
    {
        $rows = 0;
        if ($csvFile = $this->getRequest()->getFiles('csv_file')) {
            if (($handle = fopen($csvFile["tmp_name"], "r")) !== FALSE) {
                while (($data = fgetcsv($handle, 1000, ",")) !== FALSE) {
                    $num = count($data);
                    if ($num == 3) {
                        $redirect = $this->redirectFactory->create();

                        $redirect->setData([
                            'requested_path' => $data[0],
                            'target_path' => $data[1],
                            'redirect_type' => $data[2],
                            'store_id' => $data[3] ?? 0
                        ])->save();
                        $rows++;
                    }
                }
                fclose($handle);
            }
        }

        $this->messageManager->addSuccess(__('Imported %1 redirects.', $rows));
        return $this->_redirect('*/*/index');
    }
}
